# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'неділя',
        1: 'понеділок',
        2: 'вівторок',
        3: 'середа',
        4: 'четвер',
        5: 'п\'ятниця',
        6: 'субота'
    },
    'days_abbrev': {
        0: 'Нд',
        1: 'Пн',
        2: 'Вт',
        3: 'Ср',
        4: 'Чт',
        5: 'Пт',
        6: 'Сб'
    },

    # Months
    'months': {
        1: 'січня',
        2: 'лютого',
        3: 'березня',
        4: 'квітня',
        5: 'травня',
        6: 'червня',
        7: 'липня',
        8: 'серпня',
        9: 'вересня',
        10: 'жовтня',
        11: 'листопада',
        12: 'грудня'
    },
    'months_abbrev': {
        1: 'січ',
        2: 'лют',
        3: 'бер',
        4: 'квіт',
        5: 'трав',
        6: 'черв',
        7: 'лип',
        8: 'серп',
        9: 'вер',
        10: 'жовт',
        11: 'лист',
        12: 'груд'
    },

    # Units of time
    'year': ['{count} рік', '{count} роки', '{count} років'],
    'month': ['{count} місяць', '{count} місяці', '{count} місяців'],
    'week': ['{count} тиждень', '{count} тижні', '{count} тижнів'],
    'day': ['{count} день', '{count} дні', '{count} днів'],
    'hour': ['{count} година', '{count} години', '{count} годин'],
    'minute': ['{count} хвилину', '{count} хвилини', '{count} хвилин'],
    'second': ['{count} секунду', '{count} секунди', '{count} секунд'],

    # Relative time
    'ago': '{time} назад',
    'from_now': 'через {time}',
    'after': '{time} після',
    'before': '{time} до',

    # Date formats
    'date_formats': {
        'LTS': 'HH:mm:ss',
        'LT': 'HH:mm',
        'LLLL': 'dddd, D MMMM YYYY р., HH:mm',
        'LLL': 'D MMMM YYYY р., HH:mm',
        'LL': 'D MMMM YYYY р.',
        'L': 'DD.MM.YYYY',
    },
}
