# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'søndag',
        1: 'mandag',
        2: 'tirsdag',
        3: 'onsdag',
        4: 'torsdag',
        5: 'fredag',
        6: 'lørdag'
    },
    'days_abbrev': {
        0: 'sø.',
        1: 'ma.',
        2: 'ti.',
        3: 'on.',
        4: 'to.',
        5: 'fr.',
        6: 'lø.'
    },

    # Months
    'months': {
        1: 'januar',
        2: 'februar',
        3: 'mars',
        4: 'april',
        5: 'mai',
        6: 'juni',
        7: 'juli',
        8: 'august',
        9: 'september',
        10: 'oktober',
        11: 'november',
        12: 'desember'
    },
    'months_abbrev': {
        1: 'jan.',
        2: 'feb.',
        3: 'mars',
        4: 'april',
        5: 'mai',
        6: 'juni',
        7: 'juli',
        8: 'aug.',
        9: 'sep.',
        10: 'okt.',
        11: 'nov.',
        12: 'des.'
    },

    # Units of time
    'year': ['{count} år', '{count} år'],
    'month': ['{count} måned', '{count} måneder'],
    'week': ['{count} uke', '{count} uker'],
    'day': ['{count} dag', '{count} dager'],
    'hour': ['{count} time', '{count} timer'],
    'minute': ['{count} minutt', '{count} minutter'],
    'second': ['{count} sekund', '{count} sekunder'],

    # Relative time
    'ago': '{time} siden',
    'from_now': 'om {time}',
    'after': '{time} etter',
    'before': '{time} før',

    # Date formats
    'date_formats': {
        'LTS': 'HH:mm:ss',
        'LT': 'HH:mm',
        'LLLL': 'dddd D. MMMM YYYY [kl.] HH:mm',
        'LLL': 'D. MMMM YYYY [kl.] H:mm',
        'LL': 'D. MMMM YYYY',
        'L': 'DD.MM.YYYY',
    },
}
