# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'E Diel',
        1: 'E Hënë',
        2: 'E Martë',
        3: 'E Mërkurë',
        4: 'E Enjte',
        5: 'E Premte',
        6: 'E Shtunë'
    },
    'days_abbrev': {
        0: 'Die',
        1: 'Hën',
        2: 'Mar',
        3: 'Mër',
        4: 'Enj',
        5: 'Pre',
        6: 'Sht'
    },

    # Months
    'months': {
        1: 'Janar',
        2: 'Shkurt',
        3: 'Mars',
        4: 'Prill',
        5: 'Maj',
        6: 'Qershor',
        7: 'Korrik',
        8: 'Gusht',
        9: 'Shtator',
        10: 'Tetor',
        11: 'Nëntor',
        12: 'Dhjetor'
    },
    'months_abbrev': {
        1: 'Jan',
        2: 'Shk',
        3: 'Mar',
        4: 'Pri',
        5: 'Maj',
        6: 'Qer',
        7: 'Kor',
        8: 'Gus',
        9: 'Sht',
        10: 'Tet',
        11: 'Nën',
        12: 'Dhj'
    },

    # Units of time
    'year': ['{count} vit', '{count} vjet'],
    'month': ['{count} muaj', '{count} muaj'],
    'week': ['{count} javë', '{count} javë'],
    'day': ['{count} ditë', '{count} ditë'],
    'hour': ['{count} orë', '{count} orë'],
    'minute': ['{count} minutë', '{count} minuta'],
    'second': ['{count} sekondë', '{count} sekonda'],

    # Relative time
    'ago': '{time} më parë',
    'from_now': '{time} nga tani',
    'after': '{time} pas',
    'before': '{time} para',

    # Date formats
    'date_formats': {
        'LTS': 'HH:mm:ss',
        'LT': 'HH:mm',
        'LLLL': 'dddd, D MMMM YYYY HH:mm',
        'LLL': 'D MMMM YYYY HH:mm',
        'LL': 'D MMMM YYYY',
        'L': 'DD/MM/YYYY',
    },
}
