# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'Κυριακή',
        1: 'Δευτέρα',
        2: 'Τρίτη',
        3: 'Τετάρτη',
        4: 'Πέμπτη',
        5: 'Παρασκευή',
        6: 'Σάββατο'
    },
    'days_abbrev': {
        0: 'Κυρ',
        1: 'Δευ',
        2: 'Τρι',
        3: 'Τετ',
        4: 'Πεμ',
        5: 'Παρ',
        6: 'Σαβ'
    },

    # Months
    'months': {
        1: 'Ιανουαρίου',
        2: 'Φεβρουαρίου',
        3: 'Μαρτίου',
        4: 'Απριλίου',
        5: 'Μαΐου',
        6: 'Ιουνίου',
        7: 'Ιουλίου',
        8: 'Αυγούστου',
        9: 'Σεπτεμβρίου',
        10: 'Οκτωβρίου',
        11: 'Νοεμβρίου',
        12: 'Δεκεμβρίου',
    },
    'months_abbrev': {
        1: 'Ιαν',
        2: 'Φεβ',
        3: 'Μαρ',
        4: 'Απρ',
        5: 'Μαϊ',
        6: 'Ιον',
        7: 'Ιολ',
        8: 'Αυγ',
        9: 'Σεπ',
        10: 'Οκτ',
        11: 'Νοε',
        12: 'Δεκ',
    },

    # Units of time
    'year': ['{count} χρόνος', '{count} χρόνια'],
    'month': ['{count} μήνας', '{count} μήνες'],
    'week': ['{count} εβδομάδα', '{count} εβδομάδες'],
    'day': ['{count} μέρα', '{count} μέρες'],
    'hour': ['{count} ώρα', '{count} ώρες'],
    'minute': ['{count} λεπτό', '{count} λεπτά'],
    'second': ['{count} δευτερόλεπτο', '{count} δευτερόλεπτα'],

    # Relative time
    'ago': 'πρίν απο {time}',
    'from_now': 'σε {time} απο τώρα',
    'after': '{time} μετά',
    'before': '{time} πρίν',

    # Date formats
    'date_formats': {
        'LTS': 'h:mm:ss A',
        'LT': 'h:mm A',
        'LLLL': 'dddd, D MMMM YYYY h:mm A',
        'LLL': 'D MMMM YYYY h:mm A',
        'LL': 'D MMMM YYYY',
        'L': 'DD/MM/YYYY',
    },
}
