# -*- coding: utf-8 -*-

translations = {
# Days
    'days': {
        0: 'Diumenge',
        1: 'Dilluns',
        2: 'Dimarts',
        3: 'Dimecres',
        4: 'Dijous',
        5: 'Divendres',
        6: 'Dissabte'
    },
    'days_abbrev': {
        0: 'Diumenge',
        1: 'Dilluns',
        2: 'Dimarts',
        3: 'Dimecres',
        4: 'Dijous',
        5: 'Divendres',
        6: 'Dissabte'
    },

    # Months
    'months': {
        1: 'Gener',
        2: 'Febrer',
        3: 'Març',
        4: 'Abril',
        5: 'Maig',
        6: 'Juny',
        7: 'Juliol',
        8: 'Agost',
        9: 'Setembre',
        10: 'Octubre',
        11: 'Novembre',
        12: 'Desembre',
    },
    'months_abbrev': {
        1: 'Gener',
        2: 'Febrer',
        3: 'Març',
        4: 'Abril',
        5: 'Maig',
        6: 'Juny',
        7: 'Juliol',
        8: 'Agost',
        9: 'Setembre',
        10: 'Octubre',
        11: 'Novembre',
        12: 'Desembre',
    },

    # Units of time
    'year': ['{count} any', '{count} anys'],
    'month': ['{count} mes', '{count} mesos'],
    'week': ['{count} setmana', '{count} setmanes'],
    'day': ['{count} dia', '{count} díes'],
    'hour': ['{count} hora', '{count} hores'],
    'minute': ['{count} minut', '{count} minuts'],
    'second': ['{count} segon', '{count} segons'],

    # Relative time
    'ago': 'Fa {time}',
    'from_now': 'Dins de {time}',
    'after': '{time} després',
    'before': '{time} abans',

    # Date formats
    'date_formats': {
        'LTS': 'H:mm:ss',
        'LT': 'H:mm',
        'LLLL': 'dddd D MMMM YYYY H:mm',
        'LLL': 'D MMMM YYYY H:mm',
        'LL': 'D MMMM YYYY',
        'L': 'DD/MM/YYYY',
    },
}
