# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'sekmadienis',
        1: 'pirmadienis',
        2: 'antradienis',
        3: 'trečiadienis',
        4: 'ketvirtadienis',
        5: 'penktadienis',
        6: 'šeštadienis'
    },
    'days_abbrev': {
        0: 'Sek',
        1: 'Pir',
        2: 'Ant',
        3: 'Tre',
        4: 'Ket',
        5: 'Pen',
        6: 'Šeš'
    },

    # Months
    'months': {
        1: 'sausis',
        2: 'vasaris',
        3: 'kovas',
        4: 'balandis',
        5: 'gegužė',
        6: 'birželis',
        7: 'liepa',
        8: 'rugpjūtis',
        9: 'rugsėjis',
        10: 'spalis',
        11: 'lapkritis',
        12: 'gruodis'
    },
    'months_abbrev': {
        1: 'sau',
        2: 'vas',
        3: 'kov',
        4: 'bal',
        5: 'geg',
        6: 'bir',
        7: 'lie',
        8: 'rgp',
        9: 'rgs',
        10: 'spa',
        11: 'lap',
        12: 'grd'
    },

    # Units of time
    'year': ['{count} metus', '{count} metus', '{count} metų'],
    'month': ['{count} mėnesį', '{count} mėnesius', '{count} mėnesių'],
    'week': ['{count} savaitę', '{count} savaites', '{count} savaičių'],
    'day': ['{count} dieną', '{count} dienas', '{count} dienų'],
    'hour': ['{count} valandą', '{count} valandas', '{count} valandų'],
    'minute': ['{count} minutę', '{count} minutes', '{count} minučių'],
    'second': ['{count} sekundę', '{count} sekundes', '{count} sekundžių'],

    # Relative time
    'second_from_now': ['{count} sekundės', '{count} sekundžių', '{count} sekundžių'],
    'minute_from_now': ['{count} minutės', '{count} minučių', '{count} minučių'],
    'hour_from_now': ['{count} valandos', '{count} valandų', '{count} valandų'],
    'day_from_now': ['{count} dienos', '{count} dienų', '{count} dienų'],
    'week_from_now': ['{count} savaitės', '{count} savaičių', '{count} savaičių'],
    'month_from_now': ['{count} mėnesio', '{count} mėnesių', '{count} mėnesių'],
    'year_from_now': 'metų',
    'ago': 'prieš {time}',
    'from_now': 'už {time}',
    'after': 'po {time}',
    'before': '{time} nuo dabar',

    # Date formats
    'date_formats': {
        'LTS': 'HH:mm:ss',
        'LT': 'HH:mm',
        'LLLL': 'YYYY [m.] MMMM D [d.], dddd, HH:mm [val.]',
        'LLL': 'YYYY [m.] MMMM D [d.], HH:mm [val.]',
        'LL': 'YYYY [m.] MMMM D [d.]',
        'L': 'YYYY-MM-DD',
    },
}
